@@ -66,6 +66,18 @@ public:
                                    new_open_name, new_close_name);
     }
 
+    void
+    remove_simple(char *name)
+    {
+        template_remove_simple(t, name);
+    }
+
+    void
+    remove_pair(char *open_name)
+    {
+        template_remove_pair(t, open_name);
+    }
+
     void
     set_debug(int debug_level)
     {
@@ -96,6 +108,12 @@ public:
         return (tmpl)template_loop_iteration(t, loop_name);
     }
 
+    tmpl
+    fetch_loop_iteration(char *loop_name, int iteration)
+    {
+        return (tmpl)template_fetch_loop_iteration(t, loop_name, iteration);
+    }
+
     int
     parse_string(char *tmpl, char **output)
     {
